@@ -2,6 +2,8 @@
 Functionality of Amazon Web Services
 """
 
+import io
+
 import boto3
 from botocore.exceptions import ClientError
 
@@ -40,6 +42,8 @@ def upload_file(
 
     if isinstance(file, str):
         handler = s3client.upload_file
+    elif isinstance(file, bytes):
+        handler = lambda data: s3client.upload_fileobj(io.BytesIO(data))
     else:
         handler = s3client.upload_fileobj
 
